import app from './app';
import { config } from '@/utils/config';
import logger from '@/utils/logger';
import prisma from '@/utils/database';

async function startServer() {
  try {
    await prisma.$connect();
    logger.info('Database connected successfully');

    const server = app.listen(config.port, () => {
      logger.info(`Server is running on port ${config.port}`);
      logger.info(`Environment: ${config.nodeEnv}`);
      logger.info(`Health check: http://localhost:${config.port}/api/health`);
      logger.info(`Documentation: http://localhost:${config.port}/docs`);
    });

    const gracefulShutdown = () => {
      logger.info('Received shutdown signal, shutting down gracefully...');
      server.close(() => {
        logger.info('HTTP server closed');
        prisma.$disconnect()
          .then(() => {
            logger.info('Database connection closed');
            process.exit(0);
          })
          .catch((error) => {
            logger.error('Error closing database connection:', error);
            process.exit(1);
          });
      });
    };

    process.on('SIGTERM', gracefulShutdown);
    process.on('SIGINT', gracefulShutdown);

  } catch (error) {
    logger.error('Failed to start server:', error);
    process.exit(1);
  }
}

startServer();